@@ -1,12 +1,13 @@
 "Collection of generic-purpose and stand-alone functions"
 
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 
-from .factors import *
+from .math import *
 from .logical import *
 from .class_utils import *
 from .extensions import *
 from .indexes import *
 from .functools import *
+from .contextlib import *
 from .numpy import *
 from .io import *
