@@ -7,6 +7,11 @@ __all__ = [
     "count",
     "redirect_stdout",
     "FreezableDict",
+    "cache",
+    "lazy_import",
+    "setitems",
+    "commonsuffix",
+    "raiseif",
 ]
 
 import io
@@ -14,9 +19,18 @@ import os
 import sys
 import ctypes
 import tempfile
+import importlib
 from functools import wraps
 from itertools import count as _count
 from contextlib import redirect_stdout as _redirect_stdout
+from os.path import commonprefix
+
+try:
+    from functools import cache
+except ImportError:
+    from functools import lru_cache
+
+    cache = lru_cache(maxsize=None)
 
 
 class count(_count):
@@ -27,6 +41,62 @@ class count(_count):
             yield next(self)
 
 
+def lazy_import(name):
+    "Lazy import for modules"
+    # Based on: https://stackoverflow.com/questions/42703908/how-do-i-use-importlib-lazyloader
+    try:
+        return sys.modules[name]
+    except KeyError:
+        spec = importlib.util.find_spec(name)
+        if spec is None:
+            raise ImportError(f"Module not found: {name}")
+        sys.modules[name] = importlib.util.module_from_spec(spec)
+        loader = importlib.util.LazyLoader(spec.loader)
+        # Make module with proper locking and get it inserted into sys.modules.
+        loader.exec_module(sys.modules[name])
+        return sys.modules[name]
+
+
+def setitems(arr, vals):
+    "Sets items of an iterable object"
+    size = len(arr)
+    if hasattr(vals, "__len__"):
+        if len(vals) > size:
+            raise ValueError(
+                f"Values size ({len(vals)}) larger than array size ({size})"
+            )
+    else:
+        vals = (vals,) * size
+    for i, val in enumerate(vals):
+        if hasattr(arr[i], "__len__"):
+            setitems(arr[i], val)
+        else:
+            arr[i] = val
+
+
+def commonsuffix(words):
+    "Finds common suffix between list of words"
+    reverse = lambda word: word[::-1]
+    words = list(map(reverse, words))
+    return commonprefix(words)[::-1]
+
+
+def raiseif(fail, error):
+    "Decorator that raises error if condition is satisfied"
+
+    def decorator(fnc):
+        if not fail:
+            return fnc
+
+        @wraps(fnc)
+        def raiser(*args, **kwargs):
+            raise error
+
+        return raiser
+
+    return decorator
+
+
 class redirect_stdout(_redirect_stdout):
     """
     Context manager for temporarily redirecting stdout to another file.
