@@ -1,13 +1,22 @@
-from IPython.lib.pretty import pretty
 from lyncs_utils import (
     compute_property,
     static_property,
+    class_property,
     default_repr_pretty,
     add_kwargs_of,
     add_to,
     call_method,
 )
 from random import random
+import pytest
+
+try:
+    from IPython.lib.pretty import pretty
+
+    no_ipython = False
+except ImportError:
+    no_ipython = True
+mark_ipython = pytest.mark.skipif(no_ipython, reason="Ipython not available")
 
 
 class Foo:
@@ -21,6 +30,10 @@ class Foo:
     def pi():
         return 3.14
 
+    @class_property
+    def type(cls):
+        return cls
+
     @compute_property
     def random(self):
         return random()
@@ -50,11 +63,20 @@ class Foo:
 def test_add_to():
     @add_to(Foo)
     def added(self):
-        pass
+        return 1234
+
+    @add_to(Foo)
+    class Added:
+        def __new__(cls, foo):
+            return 5678
 
     assert hasattr(Foo, "added")
+    assert Foo(0).added() == added(None)
+    assert hasattr(Foo, "Added")
+    assert Foo(0).Added() == Added(None)
 
 
+@mark_ipython
 def test_repr_pretty():
     assert pretty(Foo(10)) == "Foo(10)"
     assert pretty(Foo(10, bar="bar")) == "Foo(10, bar='bar')"
@@ -85,6 +107,12 @@ def test_static_property():
     assert Foo.pi == 3.14
 
 
+def test_static_property():
+    foo = Foo(10)
+    assert foo.type == Foo
+    assert Foo.type == Foo
+
+
 def test_call_method():
     foo = Foo(10)
     assert call_method(foo, "get_length") == 10
